@@ -18,7 +18,8 @@ class StreamHandler(BaseCallbackHandler):
         if self.run_id_ignore_token == kwargs.get("run_id", False):
             return
         self.text += token
-        self.container.markdown(self.text)
+        self.container.write(self.text)
+        print(f"Callback: {self.text.replace('\n','  \n')}")
 
 class ConversationBufferMemory(LangchainConversationBufferMemory):
     pass
